# File: Extract.py

"""
This file exports a single function called extract, which knows how
to parse a well-formed URL and extract just the portion that comes after
the '?' but before any '#', and then prints out all of the key value pairs
embedded in the query string in the order they appear.  So, a call to
 
  extract("https://www.bing.com/search?q=fleabag&qs=n&first=30#nofilter")

would print out

  Key: "q", Value: "fleabag"
  Key: "qs", Value: "n"
  Key: "first", Value: "30"

"""

def extract(url):
   """
   Parses the supplied URL and prints out all 
   of the key value pairs, one per line.
   """
   qmpos = url.find('?')
   if qmpos == -1: return
   query = url[qmpos + 1:]
   hpos = query.find('#')
   if hpos != -1: query = query[:hpos]
   start = 0
   while start < len(query):
      epos = query.find('=', start)
      key = query[start:epos]
      apos = query.find('&', epos + 1)
      if apos == -1: apos = len(query)
      value = query[epos + 1: apos]
      print('Key: \"{}\", Value: \"{}\"'.format(key, value))
      start = apos + 1

def TestExtract():
   """
   Provided a simple test framework to exercise our extract function
   above.
   """
   while True:
      url = input("Enter URL [or just tap enter to quit]: ");
      if len(url) == 0: break
      extract(url)

if __name__ == "__main__":
   TestExtract()

        
        
